histore.archive.manager package
===============================

.. automodule:: histore.archive.manager
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 3

   histore.archive.manager.db

Submodules
----------

.. toctree::
   :maxdepth: 3

   histore.archive.manager.base
   histore.archive.manager.descriptor
   histore.archive.manager.fs
   histore.archive.manager.mem
   histore.archive.manager.persist
